==> kdebase_3.3.2.orig.tar.gz: kdebase-3.3.2/kcontrol/kfontinst/thumbnail/FontThumbnail.h <==
#ifndef __FONT_THUMBNAIL__H__
#define __FONT_THUMBNAIL__H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : CFontThumbnail
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 02/08/2003
// Version       : $Revision: 1.7 $ $Date: 2003/10/17 20:08:42 $
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2003
////////////////////////////////////////////////////////////////////////////////

#include <kio/thumbcreator.h>

class CFontThumbnail : public ThumbCreator
{
    public:

    CFontThumbnail();
    ~CFontThumbnail();

    bool  create(const QString &path, int width, int height, QImage &img);
    Flags flags() const;
};

#endif

==> kdebase_3.4.3.orig.tar.gz: kdebase-3.4.3/kcontrol/kfontinst/thumbnail/FontThumbnail.h <==
#ifndef __FONT_THUMBNAIL__H__
#define __FONT_THUMBNAIL__H__

////////////////////////////////////////////////////////////////////////////////
//
// Class Name    : KFI::CFontThumbnail
// Author        : Craig Drummond
// Project       : K Font Installer
// Creation Date : 02/08/2003
// Version       : $Revision$ $Date$
//
////////////////////////////////////////////////////////////////////////////////
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////////
// (C) Craig Drummond, 2003, 2004
////////////////////////////////////////////////////////////////////////////////

#include <kio/thumbcreator.h>
#include "FcEngine.h"

namespace KFI
{

class CFontThumbnail : public ThumbCreator
{
    public:

    CFontThumbnail();
    ~CFontThumbnail() {}

    bool  create(const QString &path, int width, int height, QImage &img);
    Flags flags() const;

    private:

    CFcEngine itsEngine;
};

}

#endif
